=== modified file 'breezy/patches.py'
--- breezy/patches.py	2020-09-08 02:47:27 +0000
+++ breezy/patches.py	2020-12-29 23:20:51 +0000
@@ -89,6 +89,10 @@
             raise MalformedPatchHeader("No orig name", line)
         else:
             orig_name = line[4:].rstrip(b"\n")
+            try:
+                (orig_name, orig_ts) = orig_name.split(b'\t')
+            except ValueError:
+                orig_ts = None
     except StopIteration:
         raise MalformedPatchHeader("No orig line", "")
     try:
@@ -97,9 +101,13 @@
             raise PatchSyntax("No mod name")
         else:
             mod_name = line[4:].rstrip(b"\n")
+            try:
+                (mod_name, mod_ts) = mod_name.split(b'\t')
+            except ValueError:
+                mod_ts = None
     except StopIteration:
         raise MalformedPatchHeader("No mod line", "")
-    return (orig_name, mod_name)
+    return ((orig_name, orig_ts), (mod_name, mod_ts))
 
 
 def parse_range(textrange):
@@ -320,13 +328,16 @@
         self.newname = newname
 
     def as_bytes(self):
-        return b'Binary files %s and %s differ\n' % (self.oldname, self.newname)
+        return b'Binary files %s and %s differ\n' % (
+            self.oldname, self.newname)
 
 
 class Patch(BinaryPatch):
 
-    def __init__(self, oldname, newname):
+    def __init__(self, oldname, newname, oldts=None, newts=None):
         BinaryPatch.__init__(self, oldname, newname)
+        self.oldts = oldts
+        self.newts = newts
         self.hunks = []
 
     def as_bytes(self):
@@ -334,8 +345,18 @@
         ret += b"".join([h.as_bytes() for h in self.hunks])
         return ret
 
+    @classmethod
+    def _headerline(cls, start, name, ts):
+        l = start + b' ' + name
+        if ts is not None:
+            l += b'\t%s' % ts
+        l += b'\n'
+        return l
+
     def get_header(self):
-        return b"--- %s\n+++ %s\n" % (self.oldname, self.newname)
+        return (
+            self._headerline(b'---', self.oldname, self.oldts) +
+            self._headerline(b'+++', self.newname, self.newts))
 
     def stats_values(self):
         """Calculate the number of inserts and removes."""
@@ -387,11 +408,12 @@
     '''
     iter_lines = iter_lines_handle_nl(iter_lines)
     try:
-        (orig_name, mod_name) = get_patch_names(iter_lines)
+        ((orig_name, orig_ts), (mod_name, mod_ts)) = get_patch_names(
+            iter_lines)
     except BinaryFiles as e:
         return BinaryPatch(e.orig_name, e.mod_name)
     else:
-        patch = Patch(orig_name, mod_name)
+        patch = Patch(orig_name, mod_name, orig_ts, mod_ts)
         for hunk in iter_hunks(iter_lines, allow_dirty):
             patch.hunks.append(hunk)
         return patch

=== modified file 'breezy/tests/test_patches.py'
--- breezy/tests/test_patches.py	2019-12-28 14:10:36 +0000
+++ breezy/tests/test_patches.py	2020-12-29 23:20:51 +0000
@@ -86,10 +86,21 @@
 
     def testValidPatchHeader(self):
         """Parse a valid patch header"""
+        lines = (
+            b"--- orig/commands.py\t2020-09-09 23:39:35 +0000\n"
+            b"+++ mod/dommands.py\t2020-09-09 23:39:35 +0000\n").split(b'\n')
+        (orig, mod) = get_patch_names(lines.__iter__())
+        self.assertEqual(
+            orig, (b"orig/commands.py", b'2020-09-09 23:39:35 +0000'))
+        self.assertEqual(
+            mod, (b"mod/dommands.py", b'2020-09-09 23:39:35 +0000'))
+
+    def testValidPatchHeaderMissingTimestamps(self):
+        """Parse a valid patch header"""
         lines = b"--- orig/commands.py\n+++ mod/dommands.py\n".split(b'\n')
         (orig, mod) = get_patch_names(lines.__iter__())
-        self.assertEqual(orig, b"orig/commands.py")
-        self.assertEqual(mod, b"mod/dommands.py")
+        self.assertEqual(orig, (b"orig/commands.py", None))
+        self.assertEqual(mod, (b"mod/dommands.py", None))
 
     def testInvalidPatchHeader(self):
         """Parse an invalid patch header"""
@@ -181,10 +192,10 @@
         patches = list(parse_patches(self.data_lines("binary.patch")))
         self.assertIs(BinaryPatch, patches[0].__class__)
         self.assertIs(Patch, patches[1].__class__)
-        self.assertContainsRe(patches[0].oldname, b'^bar\t')
-        self.assertContainsRe(patches[0].newname, b'^qux\t')
+        self.assertEqual(patches[0].oldname, b'bar')
+        self.assertEqual(patches[0].newname, b'qux')
         self.assertContainsRe(patches[0].as_bytes(),
-                              b'Binary files bar\t.* and qux\t.* differ\n')
+                              b'Binary files bar and qux differ\n')
 
     def test_parse_binary_after_normal(self):
         patches = list(parse_patches(

=== modified file 'breezy/tests/test_patches_data/binary.patch'
--- breezy/tests/test_patches_data/binary.patch	2009-10-14 22:08:45 +0000
+++ breezy/tests/test_patches_data/binary.patch	2020-12-29 23:20:51 +0000
@@ -1,4 +1,4 @@
-Binary files bar	2009-10-14 19:49:59 +0000 and qux	2009-10-14 19:50:35 +0000 differ
+Binary files bar and qux differ
 --- baz	2009-10-14 19:49:59 +0000
 +++ quxx	2009-10-14 19:51:00 +0000
 @@ -1 +1 @@

